@@ -8,6 +8,7 @@ from django.template.response import TemplateResponse
 from .forms import NewAlbumForm, EditAlbumForm
 #@TODO - refactor MediaAlbum model name to Album
 from .models import Album, Video, Photo
+from .utils import querydict_to_dict
 
 class AlbumListView(ListView):
     queryset = Album.objects.is_public().on_site()
@@ -35,17 +36,6 @@ class VideoListView(ListView):
 class PhotoDetailView(DetailView):
     queryset = Photo.objects.on_site().is_public()
 
-def querydict_to_dict(query_dict):
-    # request.POST only returns the first value in a list, this grabs it all
-    # Lovingly stolen from: https://tinyurl.com/h6my82s6
-    data = {}
-    for key in query_dict.keys():
-        v = query_dict.getlist(key)
-        if len(v) == 1:
-            v = v[0]
-        data[key] = v
-    return data
-
 @require_http_methods(['GET', 'POST'])
 def NewAlbum(request):
     if request.method == 'POST':
